ListQueryExecutionsFluentBuilder

Struct ListQueryExecutionsFluentBuilder 

pub struct ListQueryExecutionsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to ListQueryExecutions.

Provides a list of available query execution IDs for the queries in the specified workgroup. Athena keeps a query history for 45 days. If a workgroup is not specified, returns a list of query execution IDs for the primary workgroup. Requires you to have access to the workgroup in which the queries ran.

Implementations

Source

impl ListQueryExecutionsFluentBuilder

pub fn as_input(&self) -> &ListQueryExecutionsInputBuilder

Access the ListQueryExecutions as a reference.

pub async fn send( self, ) -> Result<ListQueryExecutionsOutput, SdkError<ListQueryExecutionsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<ListQueryExecutionsOutput, ListQueryExecutionsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn into_paginator(self) -> ListQueryExecutionsPaginator

Create a paginator for this request

Paginators are used by calling send().await which returns a PaginationStream.

pub fn next_token(self, input: impl Into<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn set_next_token(self, input: Option<String>) -> Self

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn get_next_token(&self) -> &Option<String>

A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.

pub fn max_results(self, input: i32) -> Self

The maximum number of query executions to return in this request.

pub fn set_max_results(self, input: Option<i32>) -> Self

The maximum number of query executions to return in this request.

pub fn get_max_results(&self) -> &Option<i32>

The maximum number of query executions to return in this request.

pub fn work_group(self, input: impl Into<String>) -> Self

The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.

pub fn set_work_group(self, input: Option<String>) -> Self

The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.

pub fn get_work_group(&self) -> &Option<String>

The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.