#[non_exhaustive]pub struct ListQueryExecutionsInputBuilder { /* private fields */ }Expand description
A builder for ListQueryExecutionsInput.
Implementations
Sourceimpl ListQueryExecutionsInputBuilder
impl ListQueryExecutionsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of query executions to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of query executions to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of query executions to return in this request.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup from which queries are being returned. If a workgroup is not specified, a list of available query execution IDs for the queries in the primary workgroup is returned.
Sourcepub fn build(self) -> Result<ListQueryExecutionsInput, BuildError>
pub fn build(self) -> Result<ListQueryExecutionsInput, BuildError>
Consumes the builder and constructs a ListQueryExecutionsInput.
Sourceimpl ListQueryExecutionsInputBuilder
impl ListQueryExecutionsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListQueryExecutionsOutput, SdkError<ListQueryExecutionsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListQueryExecutionsOutput, SdkError<ListQueryExecutionsError, HttpResponse>>
Sends a request with this input using the given client.