#[non_exhaustive]pub struct ListQueryExecutionsOutputBuilder { /* private fields */ }Expand description
A builder for ListQueryExecutionsOutput.
Implementations
Sourceimpl ListQueryExecutionsOutputBuilder
impl ListQueryExecutionsOutputBuilder
Sourcepub fn query_execution_ids(self, input: impl Into<String>) -> Self
pub fn query_execution_ids(self, input: impl Into<String>) -> Self
Appends an item to query_execution_ids.
To override the contents of this collection use set_query_execution_ids.
The unique IDs of each query execution as an array of strings.
Sourcepub fn set_query_execution_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_query_execution_ids(self, input: Option<Vec<String>>) -> Self
The unique IDs of each query execution as an array of strings.
Sourcepub fn get_query_execution_ids(&self) -> &Option<Vec<String>>
pub fn get_query_execution_ids(&self) -> &Option<Vec<String>>
The unique IDs of each query execution as an array of strings.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token to be used by the next request if this request is truncated.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token to be used by the next request if this request is truncated.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token to be used by the next request if this request is truncated.
Sourcepub fn build(self) -> ListQueryExecutionsOutput
pub fn build(self) -> ListQueryExecutionsOutput
Consumes the builder and constructs a ListQueryExecutionsOutput.